{
  lib, stdenv, pkgs
, extraStartupArgs ? ""
}:

pkgs.unstable.discord.overrideAttrs (old: let
    asar = pkgs.nodePackages.asar;
    gtk3 = pkgs.gtk3;
    binaryName = "Discord";
    system-electron = "$out/opt/${binaryName}/system-electron.sh";
in rec {
    version = "0.0.16";
    nativeBuildInputs = with pkgs.unstable; old.nativeBuildInputs ++ [ electron asar ];
    buildPhase = ''
      ${asar}/bin/asar e resources/app.asar resources/app
      rm resources/app.asar
      sed -i "s|process.resourcesPath|'$out/opt/${binaryName}/resources'|" resources/app/app_bootstrap/buildInfo.js
      sed -i "s|exeDir,|'$out/usr/share/pixmaps',|" resources/app/app_bootstrap/autoStart/linux.js
      ${asar}/bin/asar p resources/app resources/app.asar --unpack-dir '**'
      rm -rf resources/app
    '';
    installPhase = ''
      mkdir -p $out/{bin,opt/${binaryName},share/pixmaps}
      mv * $out/opt/${binaryName}
      echo "#!/bin/sh" > ${system-electron}
      echo "exec ${pkgs.electron}/bin/electron $out/opt/${binaryName}/resources/app.asar ${extraStartupArgs}" >> ${system-electron}
      chmod +x ${system-electron}
      chmod +x $out/opt/${binaryName}/${binaryName}
      patchelf --set-interpreter ${stdenv.cc.bintools.dynamicLinker} \
          $out/opt/${binaryName}/${binaryName}
      wrapProgram ${system-electron} \
          "''${gappsWrapperArgs[@]}" \
          --prefix XDG_DATA_DIRS : "${gtk3}/share/gsettings-schemas/${gtk3.name}/" \
          --prefix LD_LIBRARY_PATH : ${old.libPath}:$out/opt/${binaryName}
      ln -s ${system-electron} $out/bin/${binaryName}
      # Without || true the install would fail on case-insensitive filesystems
      ln -s ${system-electron} $out/bin/${lib.strings.toLower binaryName} || true
      ln -s $out/opt/${binaryName}/discord.png $out/share/pixmaps/${old.pname}.png
    '';
    desktopItem = null; 
  })
